@@ -20,13 +20,16 @@
 #pragma once
 
 #include "../common.h"
+#include "../timer.h"
 #include <vector>
 
 
 class Config {
 public:
-    Config(List configuration, CharacterVector namesVector)
+    Config(const List& configuration, const CharacterVector& namesVector)
     {
+        BLOCK_TIMER(bt, "Config::Config - load config");
+
         int nrow_i = as<IntegerVector>(configuration["nrow"])[0];
         if (nrow_i < 0)
             throw invalid_argument("nrow must be non-negative");
@@ -58,23 +61,23 @@ public:
             maxResults = static_cast<size_t>(maxResults_i);
 
         minSupport = as<NumericVector>(configuration["minSupport"])[0];
-        if (minSupport < 0.0f || minSupport > 1.0f)
+        if (minSupport < 0.0 || minSupport > 1.0)
             throw invalid_argument("minSupport must be in the range [0, 1]");
 
         minSum = minSupport * nrow;
 
         minFocusSupport = as<NumericVector>(configuration["minFocusSupport"])[0];
-        if (minFocusSupport < 0.0f || minFocusSupport > 1.0f)
+        if (minFocusSupport < 0.0 || minFocusSupport > 1.0)
             throw invalid_argument("minFocusSupport must be in the range [0, 1]");
 
         minFocusSum = minFocusSupport * nrow;
 
         minConditionalFocusSupport = as<NumericVector>(configuration["minConditionalFocusSupport"])[0];
-        if (minConditionalFocusSupport < 0.0f || minConditionalFocusSupport > 1.0f)
+        if (minConditionalFocusSupport < 0.0 || minConditionalFocusSupport > 1.0)
             throw invalid_argument("minConditionalFocusSupport must be in the range [0, 1]");
 
         maxSupport = as<NumericVector>(configuration["maxSupport"])[0];
-        if (maxSupport < 0.0f || maxSupport > 1.0f)
+        if (maxSupport < 0.0 || maxSupport > 1.0)
             throw invalid_argument("maxSupport must be in the range [0, 1]");
 
         maxSum = maxSupport * nrow;
@@ -105,97 +108,97 @@ public:
         }
     }
 
-    bool hasConditionArgument() const
+    inline bool hasConditionArgument() const
     { return conditionArgument; }
 
-    bool hasFociSupportsArgument() const
+    inline bool hasFociSupportsArgument() const
     { return fociSupportsArgument; }
 
-    bool hasContiPpArgument() const
+    inline bool hasContiPpArgument() const
     { return contiPpArgument; }
 
-    bool hasContiNpArgument() const
+    inline bool hasContiNpArgument() const
     { return contiNpArgument; }
 
-    bool hasContiPnArgument() const
+    inline bool hasContiPnArgument() const
     { return contiPnArgument; }
 
-    bool hasContiNnArgument() const
+    inline bool hasContiNnArgument() const
     { return contiNnArgument; }
 
-    bool hasAnyContiArgument() const
+    inline bool hasAnyContiArgument() const
     { return anyContiArgument; }
 
-    bool hasIndicesArgument() const
+    inline bool hasIndicesArgument() const
     { return indicesArgument; }
 
-    bool hasSumArgument() const
+    inline bool hasSumArgument() const
     { return sumArgument; }
 
-    bool hasSupportArgument() const
+    inline bool hasSupportArgument() const
     { return supportArgument; }
 
-    bool hasWeightsArgument() const
+    inline bool hasWeightsArgument() const
     { return weightsArgument; }
 
-    bool hasDisjoint() const
+    inline bool hasDisjoint() const
     { return disjointDefined; }
 
-    bool hasFilterEmptyFoci() const
+    inline bool hasFilterEmptyFoci() const
     { return filterEmptyFoci; }
 
-    bool hasFilterExcluded() const
+    inline bool hasFilterExcluded() const
     { return filterExcluded; }
 
-    bool isVerbose() const
+    inline bool isVerbose() const
     { return verbose; }
 
-    const vector<int>& getDisjoint() const
+    inline const vector<int>& getDisjoint() const
     { return disjoint; }
 
-    const List getExcluded() const
+    inline const List getExcluded() const
     { return excluded; }
 
-    size_t getNrow() const
+    inline size_t getNrow() const
     { return nrow; }
 
-    size_t getThreads() const
+    inline size_t getThreads() const
     { return threads; }
 
-    size_t getMinLength() const
+    inline size_t getMinLength() const
     { return minLength; }
 
-    size_t getMaxLength() const
+    inline size_t getMaxLength() const
     { return maxLength; }
 
-    size_t getMaxResults() const
+    inline size_t getMaxResults() const
     { return maxResults; }
 
-    float getMinSupport() const
+    inline double getMinSupport() const
     { return minSupport; }
 
-    float getMinSum() const
+    inline double getMinSum() const
     { return minSum; }
 
-    float getMinFocusSupport() const
+    inline double getMinFocusSupport() const
     { return minFocusSupport; }
 
-    float getMinFocusSum() const
+    inline double getMinFocusSum() const
     { return minFocusSum; }
 
-    float getMinConditionalFocusSupport() const
+    inline double getMinConditionalFocusSupport() const
     { return minConditionalFocusSupport; }
 
-    float getMaxSupport() const
+    inline double getMaxSupport() const
     { return maxSupport; }
 
-    float getMaxSum() const
+    inline double getMaxSum() const
     { return maxSum; }
 
-    TNorm getTNorm() const
+    inline TNorm getTNorm() const
     { return tNorm; }
 
-    const string& getChainName(size_t i) const
+    inline const string& getChainName(const size_t i) const
     { return chainNames[i]; }
 
 private:
@@ -204,13 +207,13 @@ private:
     size_t minLength;
     size_t maxLength;
     size_t maxResults;
-    float minSupport;
-    float minSum;
-    float minFocusSupport;
-    float minFocusSum;
-    float minConditionalFocusSupport;
-    float maxSupport;
-    float maxSum;
+    double minSupport;
+    double minSum;
+    double minFocusSupport;
+    double minFocusSum;
+    double minConditionalFocusSupport;
+    double maxSupport;
+    double maxSum;
     TNorm tNorm;
     List excluded;
     vector<int> disjoint;
@@ -233,7 +236,7 @@ private:
     bool supportArgument = false;
     bool weightsArgument = false;
 
-    static TNorm parseTNorm(const CharacterVector& vec)
+    static inline TNorm parseTNorm(const CharacterVector& vec)
     {
         if (vec[0] == "goguen")
             return TNorm::GOGUEN;
