@@ -21,7 +21,6 @@
 
 #include "../common.h"
 #include "../AlignedVector.h"
-#include "xsimd/xsimd.hpp"
 #include "BaseChain.h"
 
 
@@ -85,7 +84,7 @@ public:
             set(i, vec[i] ? 1.0 : 0.0);
         }
 
-        setSum();
+        internalSetSum();
     }
 
     FubitChain(size_t id, PredicateType type, const NumericVector& vec)
@@ -97,11 +96,11 @@ public:
             set(i, vec[i]);
         }
 
-        setSum();
+        internalSetSum();
     }
 
-    FubitChain(const FubitChain& a, const FubitChain& b, const bool toFocus)
-        : BaseChain(a, b, toFocus),
+    FubitChain(const FubitChain& a, const FubitChain& b)
+        : BaseChain(a, b),
           data(a.data.size()),
           n(a.n)
     {
@@ -135,9 +134,15 @@ public:
             }
         }
 
-        setSum();
+        internalSetSum();
     }
 
+    FubitChain(const FubitChain& a, const FubitChain& b, const double sum)
+        : BaseChain(a, b, sum),
+          data(),
+          n(a.n)
+    { }
+
     // Disable copy
     FubitChain(const FubitChain& other) = delete;
     FubitChain& operator=(const FubitChain& other) = delete;
@@ -146,24 +151,24 @@ public:
     FubitChain(FubitChain&& other) = default;
     FubitChain& operator=(FubitChain&& other) = default;
 
-    bool operator==(const FubitChain& other) const
+    inline bool operator==(const FubitChain& other) const
     { return BaseChain::operator==(other) && (data == other.data); }
 
-    bool operator!=(const   FubitChain& other) const
+    inline bool operator!=(const FubitChain& other) const
     { return !(*this == other); }
 
-    void set(size_t index, float value)
+    inline void set(const size_t index, const float value)
     {
         if constexpr (TNORM == TNorm::GOEDEL) {
-            internalSet(index, (BASE_TYPE) (value * MAX_VALUE));
+            internalSet(index, (BASE_TYPE) llroundf(value * MAX_VALUE));
         }
         else if constexpr (TNORM == TNorm::LUKASIEWICZ) {
-            internalSet(index, (BASE_TYPE) ((1.0 - value) * MAX_VALUE));
+            internalSet(index, (BASE_TYPE) llroundf((1.0 - value) * MAX_VALUE));
         }
         else if constexpr (TNORM == TNorm::GOGUEN) {
             static float reciprocal = 1.0 / MAX_VALUE;
             static float logLogBase = log(LOG_BASE);
-            internalSet(index, (value <= reciprocal) ? this->MAX_VALUE : round(log(value) / logLogBase));
+            internalSet(index, (value <= reciprocal) ? this->MAX_VALUE : llroundf(log(value) / logLogBase));
         }
         else {
             static_assert(TNORM != TNorm::GOEDEL && TNORM != TNorm::GOGUEN && TNORM != TNorm::LUKASIEWICZ,
@@ -171,7 +176,7 @@ public:
         }
     }
 
-    float operator[](size_t index) const
+    inline float operator[](const size_t index) const
     {
         float res = 0;
         if constexpr (TNORM == TNorm::GOEDEL) {
@@ -192,7 +197,7 @@ public:
         return res;
     }
 
-    float at(size_t index) const
+    inline float at(const size_t index) const
     {
         if (index >= n) {
             throw std::out_of_range("FubitChain::at");
@@ -201,13 +206,13 @@ public:
         return operator[](index);
     }
 
-    size_t size() const
+    inline size_t size() const
     { return n; }
 
-    bool empty() const
+    inline bool empty() const
     { return n <= 0; }
 
-    string toString() const
+    inline string toString() const
     {
         stringstream res;
         res << "[n=" << data.size() << "]";
@@ -218,7 +223,7 @@ public:
         return res.str();
     }
 
-    void printBits(BASE_TYPE value) const
+    inline void printBits(const BASE_TYPE value) const
     {
         for (size_t i = 0; i < INTEGER_SIZE; ++i) {
             std::cout << ((value >> (INTEGER_SIZE - 1 - i)) & 1);
@@ -230,7 +235,7 @@ private:
     AlignedVector<BASE_TYPE> data;
     size_t n;
 
-    void internalSet(size_t pos, BASE_TYPE value)
+    inline void internalSet(const size_t pos, const BASE_TYPE value)
     {
         size_t index = pos * BLOCK_SIZE / INTEGER_SIZE;
         size_t shift = pos * BLOCK_SIZE % INTEGER_SIZE;
@@ -238,7 +243,7 @@ private:
         //cout << "FubitChain::internalSet: value=" << value << " index=" << index << ", shift=" << shift << ", data[index]=" << data[index] << endl;
     }
 
-    BASE_TYPE internalAt(size_t pos) const
+    inline BASE_TYPE internalAt(const size_t pos) const
     {
         size_t index = pos * BLOCK_SIZE / INTEGER_SIZE;
         size_t shift = pos * BLOCK_SIZE % INTEGER_SIZE;
@@ -248,7 +253,7 @@ private:
         return (data[index] >> shift) & BLOCK_MASK;
     }
 
-    BASE_TYPE internalSum() const
+    inline BASE_TYPE internalSum() const
     {
         BASE_TYPE result = 0;
         size_t index = 0;
@@ -269,7 +274,7 @@ private:
         return result;
     }
 
-    BASE_TYPE internalCloneBits(BASE_TYPE value) const
+    inline BASE_TYPE internalCloneBits(const BASE_TYPE value) const
     {
         BASE_TYPE res = value & OVERFLOW_MASK;
 
@@ -295,7 +300,7 @@ private:
         return res;
     }
 
-    void setSum()
+    inline void internalSetSum()
     {
         if constexpr (TNORM == TNorm::GOEDEL) {
             this->sum = ((float) internalSum()) / ((float) MAX_VALUE);
