@@ -59,8 +59,8 @@ public:
         setSum();
     }
 
-    SimdChain(const SimdChain& a, const SimdChain& b, const bool toFocus)
-        : BaseChain(a, b, toFocus),
+    SimdChain(const SimdChain& a, const SimdChain& b)
+        : BaseChain(a, b),
           data(a.data.size())
     {
         IF_DEBUG(
@@ -120,6 +120,11 @@ public:
         setSum();
     }
 
+    SimdChain(const SimdChain& a, const SimdChain& b, const double sum)
+        : BaseChain(a, b, sum),
+          data()
+    { }
+
     // Disable copy
     SimdChain(const SimdChain& other) = delete;
     SimdChain& operator=(const SimdChain& other) = delete;
@@ -128,25 +133,25 @@ public:
     SimdChain(SimdChain&& other) = default;
     SimdChain& operator=(SimdChain&& other) = default;
 
-    bool operator==(const SimdChain& other) const
+    inline bool operator==(const SimdChain& other) const
     { return BaseChain::operator==(other) && (data == other.data); }
 
-    bool operator!=(const SimdChain& other) const
+    inline bool operator!=(const SimdChain& other) const
     { return !(*this == other); }
 
-    float operator[](size_t index) const
+    inline float operator[](const size_t index) const
     { return data[index]; }
 
-    float at(size_t index) const
+    inline float at(const size_t index) const
     { return data.at(index); }
 
-    size_t size() const
+    inline size_t size() const
     { return data.size(); }
 
-    bool empty() const
+    inline bool empty() const
     { return data.empty(); }
 
-    string toString() const
+    inline string toString() const
     {
         stringstream res;
         res << "[n=" << data.size() << "]";
@@ -160,7 +165,7 @@ public:
 private:
     AlignedVector<float> data;
 
-    void setSum()
+    inline void setSum()
     {
         __m256 sumv = _mm256_set1_ps(0.0f);
 
